@@ -1,5 +1,5 @@
+from collections.abc import Sequence
 from pathlib import Path
-from typing import List, Optional, Sequence, Set
 
 import blacksmith
 from blacksmith.domain.registry import HttpResource, registry
@@ -8,8 +8,6 @@ from pydantic import BaseModel, Field
 
 env = Environment(loader=PackageLoader("whitesmith"), autoescape=False)
 handlers_template = env.get_template("handlers.jinja2")
-conftest_template = env.get_template("conftest.jinja2")
-fixtures_template = env.get_template("fixtures.jinja2")
 
 sd = blacksmith.SyncRouterDiscovery(
     service_url_fmt="http://{service}.{version}",
@@ -21,6 +19,10 @@ cli: blacksmith.SyncClientFactory[blacksmith.HTTPError] = blacksmith.SyncClientF
 )
 
 
+def import_pydantic_factory() -> str:
+    return "from polyfactory.factories.pydantic_factory import ModelFactory"
+
+
 class ResponseModel(BaseModel):
     mod: str = Field(...)
     name: str = Field(...)
@@ -38,17 +40,22 @@ class Route(BaseModel):
 
 
 class HandlerTemplateContext(BaseModel):
-    whitesmith_imports: Set[str] = Field(default_factory=lambda: {"router"})
+    extra_import_lines: set[str] = Field(default_factory=set)
+    whitesmith_imports: set[str] = Field(default_factory=lambda: {"router"})
     has_missing_schema: bool = Field(default=False)
-    response_models: Set[ResponseModel] = Field(default_factory=set)
-    routes: List[Route] = Field(default_factory=list)
+    response_models: set[ResponseModel] = Field(default_factory=set)
+    routes: list[Route] = Field(default_factory=list)
+
+    @property
+    def sorted_response_models(self) -> list[ResponseModel]:
+        return sorted(self.response_models, key=lambda x: x.__class__.__name__)
 
     def add_resource(
         self,
         endpoint: str,
         service: str,
         name: str,
-        resource: Optional[HttpResource],
+        resource: HttpResource | None,
         prefix: str = "",
     ) -> "HandlerTemplateContext":
         if not resource or not resource.contract:
@@ -58,6 +65,7 @@ class HandlerTemplateContext(BaseModel):
             response_schema_name = ""
             if response_schema:
                 response_schema_name = response_schema.__name__
+                self.extra_import_lines.add(import_pydantic_factory())
                 self.response_models.add(
                     ResponseModel(
                         mod=response_schema.__module__,
@@ -86,14 +94,13 @@ class HandlerTemplateContext(BaseModel):
 def generate_handlers(
     outdir: Path, resources_mod: Sequence[str], overwrite: bool
 ) -> None:
-
     blacksmith.scan(*resources_mod)
 
     print("Generating mocks from blacksmith registry...")
 
-    outdir = outdir / "whitesmith"
+    outdir = outdir / "whitesmith_handlers"
+    outdir.mkdir(parents=True, exist_ok=True)
     for client, service in registry.client_service.items():
-
         service, resources = registry.get_service(client)
         endpoint = sd.get_endpoint(*service)
 
@@ -105,32 +112,12 @@ def generate_handlers(
                 endpoint, client, name, resource.collection, prefix="collection_"
             ).add_resource(endpoint, client, name, resource.resource)
 
-        outdir.mkdir(exist_ok=True)
         file_ = outdir / "__init__.py"
-        if overwrite or not (outdir / "__init__.py").exists():
-            print(f"Writing {file_}")
-            file_.write_text("")
-
-        file_ = outdir / "conftest.py"
-        if overwrite or not file_.exists():
-            conftest = conftest_template.render()
-            print(f"Writing {file_}")
-            file_.write_text(conftest)
-
-        file_ = outdir / "fixtures.py"
-        if overwrite or not file_.exists():
-            conftest = fixtures_template.render(context={"resources": resources_mod})
-            print(f"Writing {file_}")
-            file_.write_text(conftest)
-
-        (outdir / "handlers").mkdir(exist_ok=True)
-
-        file_ = outdir / "handlers" / "__init__.py"
         if overwrite or not file_.exists():
             print(f"Writing {file_}")
             file_.write_text("")
 
-        file_ = outdir / "handlers" / f"{client}.py"
+        file_ = outdir / f"{client}.py"
         if overwrite or not file_.exists():
             print(f"Writing {file_}")
             handler = handlers_template.render(context=context)
